# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"Client": "client.ipynb",
         "getCardToken": "client.ipynb",
         "Keys": "helper.ipynb"}

modules = ["client.py",
           "helper.py"]

doc_url = "https://thanakijwanavit.github.io/globalPrimePay/"

git_url = "https://github.com/thanakijwanavit/globalPrimePay/tree/main/"

def custom_doc_links(name): return None
